@@ -111,10 +111,10 @@ class CameraUtils:
             >>> camera.extrinsics.location
             Point(x=1.641, y=13.246,  z=0.)
         """
-        camera.extrinsics.rotation = self.calculate_rotation(camera, look_at_point=look_at_point)
+        camera.extrinsic_params.rotation = self.calculate_rotation(camera, look_at_point=look_at_point)
 
     def _get_camera_location(self, camera: Union[assets.Camera, P]) -> P:
-        return camera if isinstance(camera, (assets.Point, np.ndarray)) else camera.extrinsics.location
+        return camera if isinstance(camera, (assets.Point, np.ndarray)) else camera.extrinsic_params.location
 
     def get_extrinsic_matrix(self, camera: assets.Camera) -> "np.ndarray":
         """Calculates the extrinsic matrix of the camera.
@@ -141,7 +141,7 @@ class CameraUtils:
         return extrinsics.rotation.matrix
 
     def _get_extrinsics_from_camera_asset(self, camera: assets.Camera) -> Extrinsics:
-        camera_location, yaw_pitch_roll = to_arrays(camera.extrinsics.location, camera.extrinsics.rotation)
+        camera_location, yaw_pitch_roll = to_arrays(camera.extrinsic_params.location, camera.extrinsic_params.rotation)
         extrinsics = Extrinsics.from_yaw_pitch_roll(camera_location, yaw_pitch_roll)
         return extrinsics
 
@@ -187,9 +187,9 @@ class CameraUtils:
         if camera_intrinsics:
             camera.intrinsics = camera_intrinsics
         if camera_extrinsics:
-            camera.extrinsics = camera_extrinsics
+            camera.extrinsic_params = camera_extrinsics
         if camera_location:
-            camera.extrinsics.location = camera_location
+            camera.extrinsic_params.location = camera_location
         return camera
 
 
